
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '36.0.0',
    'branch_nick': 'master',
    'revision_id': '90f198e846c1744695da583dd23fcdbc2a778a98',
    'revno': 13350
}
